# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (C) 2012 <Elio Esteves Duarte> <elio.esteves.duarte@gmail.com>
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

import locale
from locale import gettext as _

from gi.repository import AppIndicator3, Gtk
from tomate.helpers import get_settings
from tomate.timer import Timer

locale.textdomain('tomate')


class Indicator(object):
    """Takes care of Indicator features."""

    _ICON = 'tomate-idle'
    _ATTENTION_ICON = 'tomate-attention'
    _PROGRESS_ICON_TEMPLATE = 'tomate-{0:02}'

    def __init__(self, handler):
        self.handler = handler
        self.settings = get_settings()

        # Show/Hide menuitem
        self.show_mnu = Gtk.MenuItem(_('Hide'))
        self.show_mnu.connect('activate', self.on_show_mnu_activate)

        # Quit menuitem
        quit_mnu = Gtk.MenuItem(_('Quit'))
        quit_mnu.connect('activate', Gtk.main_quit)

        # Menu
        menu = Gtk.Menu()
        menu.append(self.show_mnu)
        menu.append(Gtk.SeparatorMenuItem())
        menu.append(quit_mnu)
        menu.show_all()

        # Register the indicator object
        self.indicator = AppIndicator3.Indicator.new(
            'tomate',
            Indicator._ICON,
            AppIndicator3.IndicatorCategory.APPLICATION_STATUS)
        self.indicator.set_attention_icon(Indicator._ATTENTION_ICON)
        self.indicator.set_menu(menu)
        self.set_status_active()

    def on_show_mnu_activate(self, widget, data=None):
        """Hide/show the main window."""
        if self.handler.ui.get_visible():
            self.handler.ui.set_visible(False)
            self.show_mnu.set_label(_('Show'))
        else:
            self.handler.ui.set_visible(True)
            self.handler.ui.present()
            self.show_mnu.set_label(_('Hide'))

    def update(self):
        """Updates the indicator based on the timer."""
        if self.settings.get_boolean('show-progress-in-indicator'):
            if self.handler.timer.status == Timer.STATUS_RUNNING:
                self.set_status_active()
                percent = int(self.handler.timer.time_ratio * 100)
                # The icons show 5% steps, so we have to round
                rounded_percent = percent - percent % 5
                # There is no icon for 100%
                if rounded_percent > 99:
                    self.indicator.set_icon(Indicator._ICON)
                else:
                    icon_name = Indicator._PROGRESS_ICON_TEMPLATE.format(
                        rounded_percent)
                    self.indicator.set_icon(icon_name)
        else:
            self.indicator.set_icon(Indicator._ICON)

    def alarm(self):
        """Sets the indicator to its attention state."""
        self.update()
        self.indicator.set_status(AppIndicator3.IndicatorStatus.ATTENTION)

    def set_status_active(self):
        """Sets the indicator to is active state."""
        self.indicator.set_status(AppIndicator3.IndicatorStatus.ACTIVE)
