# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (C) 2012 <Elio Esteves Duarte> <elio.esteves.duarte@gmail.com>
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

from tomate.timer import Timer
from gi.repository import Unity


class Launcher(object):
    """Shows a progress bar in laucher when the timer is running.

    Attributes:
        handler: A reference to the Handler class.
        launcher: An Unity class instance.
    """

    def __init__(self, handler):
        """Initializes the Launcher class.

        Create a reference to the Handler class
        and create an Unity class instance.
        """
        self.handler = handler
        self.launcher = Unity.LauncherEntry.get_for_desktop_id('tomate.desktop')

    def update(self):
        """Updates the icon on the launcher.

          It checks the status of the timer, through Handler class, and
          if it is running, shows a progress bar with the timer time ratio.
        """
        if self.handler.timer.status == Timer.STATUS_RUNNING:
            self.launcher.set_property("progress", self.handler.timer.time_ratio)
            self.launcher.set_property("progress_visible", True)
        else:
            self.launcher.set_property("progress_visible", False)
