# -*- Mode: Python; coding: utf-8; indent-tabs-mode: nil; tab-width: 4 -*-
### BEGIN LICENSE
# Copyright (C) 2012 <Elio Esteves Duarte> <elio.esteves.duarte@gmail.com>
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU General Public License version 3, as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranties of
# MERCHANTABILITY, SATISFACTORY QUALITY, or FITNESS FOR A PARTICULAR
# PURPOSE.  See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program.  If not, see <http://www.gnu.org/licenses/>.
### END LICENSE

from tomate.helpers import get_media_file
import time
from gi.repository import Notify, Gst

Gst.init(None)


class OSDNotify(object):
    """Shows on-screen-display notification.

    Shows osd notification with the Notify API.

    Attributes:
        _ICON: Absolute path to the image used in notification.
        n: An Notify class instance.
    """
    _ICON = get_media_file('tomate.png')

    def __init__(self):
        """Initializes the Notify and register the application."""
        Notify.init('Application-Tomate')

    def display(self, title, message):
        """Displays the osd notification.

        Displays a osd notification with the given title and message.
        Uses the icon defined in _ICON attribute.

        Args:
            title: The title of notification.
            message: The message of notification.
        """
        n = Notify.Notification.new(title, message, OSDNotify._ICON)
        n.show()


class SoundNotify(object):
    """Plays sound.

    It is called by the Handler class to play a sound when a task is finished

    Attributes:
        _URI: Absolute path to the audio file.
        playbin: An Gstreamer element instance.
    """
    _URI = 'file://' + get_media_file('alarm.wav')

    def __init__(self):
        """Initializes the Gstreamer and register the element playbin."""
        self.playbin = Gst.ElementFactory.make('playbin', None)
        self.playbin.set_property('uri', SoundNotify._URI)

    def alarm(self):
        """Plays the sound."""
        self.playbin.set_state(Gst.State.PLAYING)
        time.sleep(1)
        self.playbin.set_state(Gst.State.NULL)
